@@ -1,9 +1,11 @@
 #!/usr/bin/env python3
 
 import os
+import pathlib
 import sys
 
 import ruyi
+from ruyi.i18n import _, ADAPTER
 from ruyi.utils.ci import is_running_in_ci
 from ruyi.utils.global_mode import (
     EnvGlobalModeProvider,
@@ -41,6 +43,8 @@ def _is_allowed_to_run_as_root() -> bool:
 
 def entrypoint() -> None:
     gm = EnvGlobalModeProvider(os.environ, sys.argv)
+    ADAPTER.init_from_env(os.environ)
+    ADAPTER.hook()
 
     # NOTE: import of `ruyi.log` takes ~90ms on my machine, so initialization
     # of logging is deferred as late as possible
@@ -50,11 +54,16 @@ def entrypoint() -> None:
 
         logger = RuyiConsoleLogger(gm)
 
-        logger.F("refusing to run as super user outside CI without explicit consent")
+        logger.F(_("refusing to run as super user outside CI without explicit consent"))
 
         choices = ", ".join(f"'{x}'" for x in TRUTHY_ENV_VAR_VALUES)
         logger.I(
-            f"re-run with environment variable [yellow]{ENV_FORCE_ALLOW_ROOT}[/] set to one of [yellow]{choices}[/] to signify consent"
+            _(
+                "re-run with environment variable [yellow]{env_var}[/] set to one of [yellow]{choices}[/] to signify consent"
+            ).format(
+                env_var=ENV_FORCE_ALLOW_ROOT,
+                choices=choices,
+            )
         )
         sys.exit(1)
 
@@ -63,7 +72,7 @@ def entrypoint() -> None:
 
         logger = RuyiConsoleLogger(gm)
 
-        logger.F("no argv?")
+        logger.F(_("no argv?"))
         sys.exit(1)
 
     if gm.is_packaged and ruyi.__compiled__.standalone:
@@ -85,8 +94,11 @@ def entrypoint() -> None:
     #
     # we assume the one-file build if Nuitka is detected; sys.argv[0] does NOT
     # work if it's just `ruyi` so we have to check our parent process in that case
-    self_exe = get_nuitka_self_exe() if gm.is_packaged else __file__
     sys.argv[0] = get_argv0()
+    if gm.is_packaged:
+        self_exe = get_nuitka_self_exe()
+    else:
+        self_exe = str(pathlib.Path(sys.argv[0]).resolve())
     gm.record_self_exe(sys.argv[0], __file__, self_exe)
 
     from ruyi.config import GlobalConfig
