@@ -1,6 +1,7 @@
 import argparse
 from typing import TYPE_CHECKING
 
+from ..i18n import _
 from .list_cli import ListCommand
 
 if TYPE_CHECKING:
@@ -11,7 +12,7 @@ if TYPE_CHECKING:
 class ListProfilesCommand(
     ListCommand,
     cmd="profiles",
-    help="List all available profiles",
+    help=_("List all available profiles"),
 ):
     @classmethod
     def configure_args(cls, gc: "GlobalConfig", p: "ArgumentParser") -> None:
@@ -28,6 +29,11 @@ class ListProfilesCommand(
                     logger.stdout(p.id)
                     continue
 
-                logger.stdout(f"{p.id} (needs quirks: {p.need_quirks})")
+                logger.stdout(
+                    _("{profile_id} (needs quirks: {need_quirks})").format(
+                        profile_id=p.id,
+                        need_quirks=p.need_quirks,
+                    )
+                )
 
         return 0
